# Panther
<hr/>

## Requirements
<div class="termy">

```console
Python 3.10+
```
</div>

<hr/>

## Installation

<div class="termy">

```console
$ pip install rubika-bot
```
</div>

## Usage
- #### Get Your Bot Information
    <div class="termy">
    
    ```console
    from rubika import get_me
    from rubika
    bot: Bot = get_me(token=...)
    ```
    </div>

- #### Send Keypad
    <div class="termy">
    
    ```console
    ...
    ```
    </div>

